/*
 * TinyD_Rev4.cpp
 *
 * Created: 1/1/2017 1:00:11 PM
 * Author : George Gardner
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * Fuses
 * Extended 0xFF
 * High		0xDF
 * Low		0xD2
 */



#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{
	DDRB |= (1<<1);							//out1
	DDRB |= (1<<4);							//out2
	DDRB |= (1<<0);							//LED
	
	sei();									//enable global interrupts
	
    //Setup ADC
	ADCSRA |= (1<<ADEN);					//ADC enable
	ADMUX |= (1<<REFS1);					//Internal 1.1v voltage reference
	ADMUX |= (1<<ADLAR);					//ADC left adjust result
	ADCSRA |= (1<<ADIE);					//ADC interrupt enable
	ADCSRA |= (1<<ADPS2);					//Prescaler = 16 (samples taken at ~64kHz (~32kHz for each channel))
	ADCSRA |= (1<<ADSC);					//ADC start conversion
	
	//Setup timer1
	TCCR1 |= (1<<PWM1A);					//pulse width modulator A enable
	TCCR1 |= (1<<COM1A1) | (1<<COM1A0);		//set on compare match, clear at tcnt1 = 0
	TCCR1 |= (1<<CS10);						//PCK = CK
	GTCCR |= (1<<PWM1B);					//pulse width modulator B enable
	GTCCR |= (1<<COM1B1) | (1<<COM1B0);		//set on compare match, clear at tcnt1 = 0
	OCR1C = 0xff;
		
    while (1) 
    {
    }
}

ISR(ADC_vect){
	if(ADMUX == 0xA3){
		OCR1A = ADCH;
		ADMUX = 0xA1;
	} else {
		OCR1B = ADCH;
		ADMUX = 0xA3;
	}
	ADCSRA |= (1<<ADSC);					//run next conversion
}

